==> eiffelstudio-18.11.10.2592.tar: F_code/C12/as567.c <==
/*
 * Code for class AST_INLINE_AGENT_LOOKUP
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "as567.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {AST_INLINE_AGENT_LOOKUP}.lookup_inline_agent_of_feature */
EIF_REFERENCE F657_9286 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTGC;
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) NULL;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_INTEGER_32) arg2;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	if ((EIF_BOOLEAN)(tr1 != NULL)) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_4_);
		loc1 = tr1;
		loc1 = RTRV(eif_new_type(3519, 0x00),loc1);
		if (EIF_TEST(loc1)) {
			{
				/* INLINED CODE (process) */
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R7727[Dtype(Current)-651])(Current, loc1);
				/* END INLINED CODE */
			}
			;
		}
	}
	RTLE;
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current);
}

/* {AST_INLINE_AGENT_LOOKUP}.lookup_inline_agent_of_invariant */
EIF_REFERENCE F657_9287 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,arg1);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) NULL;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_INTEGER_32) arg2;
	loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	if ((EIF_BOOLEAN)(loc1 != NULL)) {
		{
			/* INLINED CODE (start) */
			*(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_2_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
			/* END INLINED CODE */
		}
		;
		for (;;) {
			tb1 = '\01';
			if (!(EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current) != NULL)) {
				{
					/* INLINED CODE (after) */
					tb2 = (EIF_BOOLEAN)  0;
					ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_2_1_0_0_);
					ti4_2 = F1501_14880(RTCW(loc1));
					tb2 = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == (EIF_INTEGER_32) (ti4_2 + ((EIF_INTEGER_32) 1L)));
					/* END INLINED CODE */
				}
				tb2 = tb2;
				tb1 = tb2;
			}
			if (tb1) break;
			tr1 = F1501_14864(RTCW(loc1));
			tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_);
			{
				/* INLINED CODE (safe_process) */
				if ((EIF_BOOLEAN)(tr1 != NULL)) {
					(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R30446[Dtype(tr1)-3488])(RTCW(tr1), Current);
				}
				/* END INLINED CODE */
			}
			;
			{
				/* INLINED CODE (forth) */
				(*(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_2_1_0_0_))++;
				/* END INLINED CODE */
			}
			;
		}
		RTLE;
		return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current);
	}
	RTLE;
	return (EIF_REFERENCE) 0;
}

/* {AST_INLINE_AGENT_LOOKUP}.process_inline_agent_creation_as */
void F657_9288 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_))--;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_) == ((EIF_INTEGER_32) 0L))) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	} else {
		F655_9090(Current, arg1);
	}
	RTLE;
}

/* {AST_INLINE_AGENT_LOOKUP}.process_eiffel_list */
void F657_9289 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	loc1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_2_1_0_0_);
	{
		/* INLINED CODE (start) */
		*(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_2_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		/* END INLINED CODE */
	}
	;
	for (;;) {
		tb1 = '\01';
		if (!(EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current) != NULL)) {
			{
				/* INLINED CODE (after) */
				tb2 = (EIF_BOOLEAN)  0;
				ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_2_1_0_0_);
				ti4_2 = F1501_14880(RTCW(arg1));
				tb2 = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == (EIF_INTEGER_32) (ti4_2 + ((EIF_INTEGER_32) 1L)));
				/* END INLINED CODE */
			}
			tb2 = tb2;
			tb1 = tb2;
		}
		if (tb1) break;
		tr1 = F1501_14864(RTCW(arg1));
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R30446[Dtype(tr1)-3488])(RTCW(tr1), Current);
		{
			/* INLINED CODE (forth) */
			(*(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_2_1_0_0_))++;
			/* END INLINED CODE */
		}
		;
	}
	{
		/* INLINED CODE (go_i_th) */
		*(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_2_1_0_0_) = (EIF_INTEGER_32) loc1;
		/* END INLINED CODE */
	}
	;
	RTLE;
}

/* {AST_INLINE_AGENT_LOOKUP}.found_inline_agent */
EIF_REFERENCE F657_9291 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


void EIF_Minit567 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C12/as567.c <==
/*
 * Code for class AST_INLINE_AGENT_LOOKUP
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "as567.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {AST_INLINE_AGENT_LOOKUP}.lookup_inline_agent_of_feature */
EIF_REFERENCE F670_9169 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTGC;
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) NULL;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_INTEGER_32) arg2;
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	if ((EIF_BOOLEAN)(tr1 != NULL)) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_4_);
		loc1 = tr1;
		loc1 = RTRV(eif_new_type(3558, 0x00),loc1);
		if (EIF_TEST(loc1)) {
			{
				/* INLINED CODE (ROUTINE_AS.process) */
				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R7670[Dtype(Current)-667])(Current, loc1);
				/* END INLINED CODE */
			}
			;
		}
	}
	RTLE;
	return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current);
}

/* {AST_INLINE_AGENT_LOOKUP}.lookup_inline_agent_of_invariant */
EIF_REFERENCE F670_9170 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,arg1);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) NULL;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_INTEGER_32) arg2;
	loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	if ((EIF_BOOLEAN)(loc1 != NULL)) {
		{
			/* INLINED CODE (ARRAYED_LIST.start) */
			*(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_2_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
			/* END INLINED CODE */
		}
		;
		for (;;) {
			tb1 = '\01';
			if (!(EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current) != NULL)) {
				{
					/* INLINED CODE (LIST.after) */
					tb2 = (EIF_BOOLEAN)  0;
					ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_2_1_0_0_);
					ti4_2 = F1523_14961(RTCW(loc1));
					tb2 = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == (EIF_INTEGER_32) (ti4_2 + ((EIF_INTEGER_32) 1L)));
					/* END INLINED CODE */
				}
				tb2 = tb2;
				tb1 = tb2;
			}
			if (tb1) break;
			{
				/* INLINED CODE (ARRAYED_LIST.item) */
				tr1 = (EIF_REFERENCE)  0;
				tr1 = *(EIF_REFERENCE *)(RTCW(loc1));
				tr1 = 
					/* INLINED CODE (SPECIAL.item) */
					*((EIF_REFERENCE *)RTCW(tr1) + ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_2_1_0_0_) - ((EIF_INTEGER_32) 1L))))
					/* END INLINED CODE */;
				/* END INLINED CODE */
			}
			tr1 = tr1;
			tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_);
			{
				/* INLINED CODE (AST_VISITOR.safe_process) */
				if ((EIF_BOOLEAN)(tr1 != NULL)) {
					(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R30630[Dtype(RTCW(tr1))-3527])(tr1, Current);
				}
				/* END INLINED CODE */
			}
			;
			{
				/* INLINED CODE (ARRAYED_LIST.forth) */
				(*(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_2_1_0_0_))++;
				/* END INLINED CODE */
			}
			;
		}
		RTLE;
		return (EIF_REFERENCE) *(EIF_REFERENCE *)(Current);
	}
	RTLE;
	return (EIF_REFERENCE) 0;
}

/* {AST_INLINE_AGENT_LOOKUP}.process_inline_agent_creation_as */
void F670_9171 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_))--;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_) == ((EIF_INTEGER_32) 0L))) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	} else {
		{
			/* INLINED CODE (AST_ITERATOR.process_inline_agent_creation_as) */
			tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
			F664_8478(Current, tr1);
			tr1 = F3658_43437(RTCW(arg1));
			F664_8478(Current, tr1);
			/* END INLINED CODE */
		}
		;
	}
	RTLE;
}

/* {AST_INLINE_AGENT_LOOKUP}.process_eiffel_list */
void F670_9172 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	loc1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_2_1_0_0_);
	{
		/* INLINED CODE (ARRAYED_LIST.start) */
		*(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_2_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		/* END INLINED CODE */
	}
	;
	for (;;) {
		tb1 = '\01';
		if (!(EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current) != NULL)) {
			{
				/* INLINED CODE (LIST.after) */
				tb2 = (EIF_BOOLEAN)  0;
				ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_2_1_0_0_);
				ti4_2 = F1523_14961(RTCW(arg1));
				tb2 = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == (EIF_INTEGER_32) (ti4_2 + ((EIF_INTEGER_32) 1L)));
				/* END INLINED CODE */
			}
			tb2 = tb2;
			tb1 = tb2;
		}
		if (tb1) break;
		{
			/* INLINED CODE (ARRAYED_LIST.item) */
			tr1 = (EIF_REFERENCE)  0;
			tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
			tr1 = 
				/* INLINED CODE (SPECIAL.item) */
				*((EIF_REFERENCE *)RTCW(tr1) + ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_2_1_0_0_) - ((EIF_INTEGER_32) 1L))))
				/* END INLINED CODE */;
			/* END INLINED CODE */
		}
		tr1 = tr1;
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R30630[Dtype(RTCW(tr1))-3527])(tr1, Current);
		{
			/* INLINED CODE (ARRAYED_LIST.forth) */
			(*(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_2_1_0_0_))++;
			/* END INLINED CODE */
		}
		;
	}
	{
		/* INLINED CODE (ARRAYED_LIST.go_i_th) */
		*(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_2_1_0_0_) = (EIF_INTEGER_32) loc1;
		/* END INLINED CODE */
	}
	;
	RTLE;
}

void EIF_Minit567 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
